OsmBounds class
Bounds of the OSM data
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxLat → double
-
Maximum latitude
final
- maxLon → double
-
Maximum longitude
final
- minLat → double
-
Minimum latitude
final
- minLon → double
-
Minimum longitude
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited