OsmData class

OSM data model

Constructors

OsmData({required List<OsmNode> nodes, required List<OsmWay> ways, required List<OsmRelation> relations, OsmBounds? bounds})
OsmData default constructor
OsmData.fromBytes(Uint8List data)
Parse pbf data and return OsmData object
factory

Properties

bounds OsmBounds?
Bounds (optional)
final
hashCode int
The hash code for this object.
no setterinherited
nodes List<OsmNode>
List of nodes
final
relations List<OsmRelation>
List of relations
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ways List<OsmWay>
List of ways
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited