OsmNode class

OSM node

Constructors

OsmNode({required int id, required Map<String, String> tags, required double lat, required double lon})
OsmNode default constructor

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
finalinherited
lat double
Latitude
final
lon double
Longitude
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags Map<String, String>
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited