OsmWay class

OSM way

Constructors

OsmWay({required int id, required Map<String, String> tags, required List<int> refs})
OsmWay default constructor

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
finalinherited
refs List<int>
List of node references that make up the way
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags Map<String, String>
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited