visible property

  1. @TagNumber.new(6)
List<bool> get visible

The visible flag is used to store history information. It indicates that the current object version has been created by a delete operation on the OSM API. When a writer sets this flag, it MUST add a required_features tag with value "HistoricalInformation" to the HeaderBlock. If this flag is not available for some object it MUST be assumed to be true if the file has the required_features tag "HistoricalInformation" set.

Implementation

@$pb.TagNumber(6)
$core.List<$core.bool> get visible => $_getList(5);