OsmRelation class
OSM relation
Constructors
-
OsmRelation({required int id, required Map<
String, String> tags, required List<int> members, required List<MemberType> types}) - OsmRelation default constructor
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
finalinherited
-
members
→ List<
int> -
List of ids of the members that make up the relation
Should be the same length as types
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
finalinherited
-
types
→ List<
MemberType> -
List of types of the members that make up the relation
Should be the same length as members
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited