visible property
The visible flag is used to store history information. It indicates that the current object version has been created by a delete operation on the OSM API. When a writer sets this flag, it MUST add a required_features tag with value "HistoricalInformation" to the HeaderBlock. If this flag is not available for some object it MUST be assumed to be true if the file has the required_features tag "HistoricalInformation" set.
Implementation
@$pb.TagNumber(6)
$core.bool get visible => $_getBF(5);
Implementation
@$pb.TagNumber(6)
set visible($core.bool v) { $_setBool(5, v); }